File Formats

File Formats#

SAM uses the following types of files to store and transfer data. The file formats are listed below by file extension in alphabetical order.

BMP

Graphics file format used to export graph images.

CSV

Text file containing a table of comma-delimited columns that SAM uses to export results data from graphs and tables, store library data, and for weather files .

EPW

EPW weather file format for EnergyPlus weather files.

JPG

Graphics file format used to export graph images.

LK

Text file containing LK script for automating SAM analyses.

PNG

Graphics file format used to export graph images.

SAM

File format for SAM project files. Stores inputs and results.

SAMREPORT

File format used to store report templates.

SRW

Obsolete file format for wind resource data.

TM2

Deprecated weather file format from old versions of the NSRDB.

XLSX

Excel files used to export data from SAM and to exchange data between the model and Excel.

ZSAM

An obsolete file format for SAM project files (SAM 2014.1.14 and earlier). SAM cannot import files in the .zsam format.