Owl is designed to be used by the Odoo javascript framework. Since Odoo handles its assets in its own non standard way, it was decided/assumed that Owl would compile templates at runtime.
However, in some cases, it is not optimal, or even worse, not possible to do that.
For example, browser extensions do not allow javascript code to create a new
function (using the new Function(...) syntax).
Therefore, in these cases, it is required to compile templates ahead of time. It is possible to do that in Owl, but the tooling is still rough. For now, the process is the following:
t-name directive to declare the name
of the template)templates.js fileowl.iife.runtime.js file (which is a owl build without the compiler)owl.iife.runtime.js and template.js with your assets (owl needs to
be positioned before the templates)Here is a more detailed explanation on how to compile xml files into a js file:
npm install to install all the required toolingnpm run build:runtime to build the owl.iife.runtime.js filenpm run build:compiler to build the template compilernpm run compile_templates -- path/to/your/templates will scan your target
folder, find all xml files, get all templates, compile them, and generate a
templates.js file.