client.geojson_available
client.geojson_available(values, filter_by, **path_kwargs)Whether GeoJSON files exist for these parameters.
No GeoJSON file is published from 2025 onwards, so no request is made for them. For earlier years, the file of the first value is checked with a HEAD request: a year republished by the current pipeline only has GeoParquet.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| values | list | Values of filter_by. |
required |
| filter_by | str | Level used to split the files. | required |
| **path_kwargs | Other arguments of create_path_bucket. |
{} |
Returns
| Name | Type | Description |
|---|---|---|
| bool |